<?php
session_start();

// Verificar si el usuario está autenticado y tiene privilegios
if (!isset($_SESSION['usuario_id']) || $_SESSION['usuario_rol'] !== 'admin') {
    header("Location: ../login.php"); // Redirigir al login si no tiene privilegios
    exit();
}

include '../../includes/db_connect.php';

// Inicializar variables
$compras = [];
$mensaje = '';
$error = '';
$busqueda = '';

// Procesar el cambio de estado de los números
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['cambiar_estado'])) {
    $id_compra = intval($_POST['id_compra']);
    $nuevo_estado = htmlspecialchars($_POST['nuevo_estado']);

    // Validar el estado
    if (!in_array($nuevo_estado, ['espera', 'confirmado', 'rechazado'])) {
        $error = "Estado no válido.";
    } else {
        // Si el estado es "rechazado", eliminamos la compra
        if ($nuevo_estado == 'rechazado') {
            // Eliminar el registro de la compra de la base de datos
            $sql = "DELETE FROM compras_rifa WHERE id = ?";
            $stmt = $conn->prepare($sql);
            if (!$stmt) {
                $error = "Error en la preparación de la consulta para eliminar: " . $conn->error;
            } else {
                $stmt->bind_param("i", $id_compra);
                if ($stmt->execute()) {
                    $mensaje = "Compra eliminada correctamente.";
                } else {
                    $error = "Error al eliminar la compra: " . $stmt->error;
                }
                $stmt->close();
            }
        } else {
            // Si no es "rechazado", solo actualizamos el estado
            $sql = "UPDATE compras_rifa SET estado = ? WHERE id = ?";
            $stmt = $conn->prepare($sql);
            if (!$stmt) {
                $error = "Error en la preparación de la consulta para actualizar el estado: " . $conn->error;
            } else {
                $stmt->bind_param("si", $nuevo_estado, $id_compra);

                if ($stmt->execute()) {
                    $mensaje = "Estado actualizado con éxito.";
                } else {
                    $error = "Error al actualizar el estado: " . $stmt->error;
                }

                $stmt->close();
            }
        }
    }
}

// Procesar la búsqueda
if ($_SERVER['REQUEST_METHOD'] === 'GET' && isset($_GET['busqueda'])) {
    $busqueda = htmlspecialchars($_GET['busqueda']);

    // Obtener todas las compras de la tabla compras_rifa con filtro de búsqueda
    $sql = "SELECT id, id_rifa, numeros_comprados, nombre, apellido, cedula, telefono, correo, estado, foto_comprobante 
            FROM compras_rifa 
            WHERE id_rifa LIKE ? 
               OR nombre LIKE ? 
               OR apellido LIKE ? 
               OR cedula LIKE ? 
               OR telefono LIKE ? 
               OR correo LIKE ?";

    $stmt = $conn->prepare($sql);
    if (!$stmt) {
        $error = "Error en la preparación de la consulta: " . $conn->error;
    } else {
        $param_busqueda = "%$busqueda%";
        $stmt->bind_param("ssssss", $param_busqueda, $param_busqueda, $param_busqueda, $param_busqueda, $param_busqueda, $param_busqueda);

        if ($stmt->execute()) {
            $result = $stmt->get_result();
            if ($result->num_rows > 0) {
                while ($row = $result->fetch_assoc()) {
                    $compras[] = $row;
                }
            }
        } else {
            $error = "Error al ejecutar la consulta: " . $stmt->error;
        }

        $stmt->close();
    }
} else {
    // Obtener todas las compras de la tabla compras_rifa sin filtro
    $sql = "SELECT id, id_rifa, numeros_comprados, nombre, apellido, cedula, telefono, correo, estado, foto_comprobante 
            FROM compras_rifa";

    $result = $conn->query($sql);

    if ($result) {
        if ($result->num_rows > 0) {
            while ($row = $result->fetch_assoc()) {
                $compras[] = $row;
            }
        }
    } else {
        $error = "Error al ejecutar la consulta: " . $conn->error;
    }
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Tabla de Clientes</title>
    <link rel="stylesheet" href="/pagaturifa/assets/css/tabla.css">
</head>
<body>
    <div class="container mt-5">
        <h2>Registro de Compras de Rifa</h2>

        <!-- Formulario de búsqueda -->
        <form method="GET" action="" class="mb-4">
            <div class="input-group">
                <input type="text" name="busqueda" class="form-control" placeholder="Buscar por número de rifa, nombre, apellido, cédula, teléfono o correo" value="<?php echo $busqueda; ?>">
                <button type="submit" class="btn btn-primary">Buscar</button>
            </div>
        </form>

        <?php if ($mensaje): ?>
            <div class="alert alert-success"><?php echo $mensaje; ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo $error; ?></div>
        <?php endif; ?>

        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>ID Rifa</th>
                    <th>Números Comprados</th>
                    <th>Nombre</th>
                    <th>Apellido</th>
                    <th>Cédula</th>
                    <th>Teléfono</th>
                    <th>Correo</th>
                    <th>Estado</th>
                    <th>Comprobante</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($compras)): ?>
                    <tr>
                        <td colspan="11" class="text-center">No se encontraron resultados.</td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($compras as $compra): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($compra['id']); ?></td>
                            <td><?php echo htmlspecialchars($compra['id_rifa']); ?></td>
                            <td><?php echo htmlspecialchars($compra['numeros_comprados']); ?></td>
                            <td><?php echo htmlspecialchars($compra['nombre']); ?></td>
                            <td><?php echo htmlspecialchars($compra['apellido']); ?></td>
                            <td><?php echo htmlspecialchars($compra['cedula']); ?></td>
                            <td><?php echo htmlspecialchars($compra['telefono']); ?></td>
                            <td><?php echo htmlspecialchars($compra['correo']); ?></td>
                            <td><?php echo htmlspecialchars($compra['estado']); ?></td>
                            <td>
                                <?php if ($compra['foto_comprobante']): ?>
                                    <a href="/pagaturifa/pagos_ima/<?php echo htmlspecialchars($compra['foto_comprobante']); ?>" target="_blank">Ver Comprobante</a>
                                <?php else: ?>
                                    Sin comprobante
                                <?php endif; ?>
                            </td>
                            <td>
                                <form method="POST" action="">
                                    <input type="hidden" name="id_compra" value="<?php echo htmlspecialchars($compra['id']); ?>">
                                    <select name="nuevo_estado">
                                        <option value="espera" <?php echo $compra['estado'] == 'espera' ? 'selected' : ''; ?>>Espera</option>
                                        <option value="confirmado" <?php echo $compra['estado'] == 'confirmado' ? 'selected' : ''; ?>>Confirmado</option>
                                        <option value="rechazado" <?php echo $compra['estado'] == 'rechazado' ? 'selected' : ''; ?>>Rechazado</option>
                                    </select>
                                    <button type="submit" name="cambiar_estado" class="btn btn-primary btn-sm">Cambiar</button>
                                </form>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
</body>
</html>
